# Bookdog
Simple book database tracker.  Currently being rewritten to use QT

## TODO

* add about dialog with copyright, license, and version
* filters (but maybe not as important with the sorted view?)
* do I want menus instead of button? in addition to?
* Packaging:
  * move main.py to __main__.py and fixup
  * get versioning cleaned up and bumpversion working correctly
  * continue with https://realpython.com/pypi-publish-python-package/#publish-your-package-to-pypi
